@@ -95,11 +95,11 @@ func TestLexTapeFile(t *testing.T) {
 		{COMMENT, " All Commands"},
 		{COMMENT, " Output:"},
 		{OUTPUT, "Output"},
-		{STRING, "all.gif"},
+		{STRING, "examples/fixtures/all.gif"},
 		{OUTPUT, "Output"},
-		{STRING, "all.mp4"},
+		{STRING, "examples/fixtures/all.mp4"},
 		{OUTPUT, "Output"},
-		{STRING, "all.webm"},
+		{STRING, "examples/fixtures/all.webm"},
 		{COMMENT, " Settings:"},
 		{SET, "Set"},
 		{FONT_SIZE, "FontSize"},
